@@ -20,7 +20,8 @@ __all__ = ['AuxiliaryBookStart', 'PrintAuxiliaryBook', 'AuxiliaryBook',
         'PrintAuxiliaryParty', 'AuxiliaryParty', 'AuxiliaryPartyStart',
         'PrintTrialBalanceStart', 'PrintTrialBalance', 'TrialBalance',
         'BalanceSheet', 'IncomeStatement', 'OpenCashflowStatement', 'Cashflow',
-        'CashflowTemplate', 'OpenCashflowStart', 'Account']
+        'CashflowTemplate', 'OpenCashflowStart', 'Account',
+        ]
 
 __metaclass__ = PoolMeta
 
@@ -1049,6 +1050,10 @@ class Cashflow(ModelSQL, ModelView):
     company = fields.Many2One('company.company', 'Company', required=True,
             ondelete="RESTRICT")
     template = fields.Many2One('account.account.cashflow.template', 'Template')
+    accounts = fields.One2Many('account.account', 'cashflow', 'Accounts',
+            add_remove=[], domain=[ 
+                ('kind', '!=', 'view'),
+            ])
 
     @classmethod
     def __setup__(cls):
